@@ -16,14 +16,14 @@ chllab <- function(logspace = TRUE){
 
   # default
   label <- expression(
-    paste('log-Chloropyhll-',italic(a),' (',italic('\u03bc'),'g ',L^-1,')')
+    paste('log-Chloropyhll-',italic(a),' (',italic(mu),'g ',L^-1,')')
     )
 
   # back-transform if needed
   if(!logspace){
     
     label <- expression(
-      paste('Chloropyhll-',italic(a),' (',italic('\u03bc'),'g ',L^-1,')')
+      paste('Chloropyhll-',italic(a),' (',italic(mu),'g ',L^-1,')')
     )
   }
   
